==> 4.5.0.tar.gz: terraform-provider-decort/internal/service/cloudbroker/lb/resource_lb_frontend.go <==
/*
Copyright (c) 2019-2023 Digital Energy Cloud Solutions LLC. All Rights Reserved.
Authors:
Petr Krutov, <petr.krutov@digitalenergy.online>
Stanislav Solovev, <spsolovev@digitalenergy.online>
Kasim Baybikov, <kmbaybikov@basistech.ru>

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

/*
Terraform DECORT provider - manage resources provided by DECORT (Digital Energy Cloud
Orchestration Technology) with Terraform by Hashicorp.

Source code: https://repository.basistech.ru/BASIS/terraform-provider-decort

Please see README.md to learn where to place source code so that it
builds seamlessly.

Documentation: https://repository.basistech.ru/BASIS/terraform-provider-decort/wiki
*/

package lb

import (
	"context"
	"strconv"
	"strings"

	"github.com/hashicorp/terraform-plugin-sdk/v2/diag"
	"github.com/hashicorp/terraform-plugin-sdk/v2/helper/schema"
	log "github.com/sirupsen/logrus"
	"repository.basistech.ru/BASIS/decort-golang-sdk/pkg/cloudbroker/lb"
	"repository.basistech.ru/BASIS/terraform-provider-decort/internal/constants"
	"repository.basistech.ru/BASIS/terraform-provider-decort/internal/controller"
)

func resourceLBFrontendCreate(ctx context.Context, d *schema.ResourceData, m interface{}) diag.Diagnostics {
	log.Debugf("resourceLBFrontendCreate")

	haveLBID, err := existLBID(ctx, d, m)
	if err != nil {
		return diag.FromErr(err)
	}

	if !haveLBID {
		return diag.Errorf("resourceLBFrontendCreate: can't create LB frontend because LBID %d is not allowed or does not exist", d.Get("lb_id").(int))
	}

	c := m.(*controller.ControllerCfg)
	req := lb.FrontendCreateRequest{
		BackendName:  d.Get("backend_name").(string),
		LBID:         uint64(d.Get("lb_id").(int)),
		FrontendName: d.Get("name").(string),
	}

	_, err = c.CloudBroker().LB().FrontendCreate(ctx, req)
	if err != nil {
		return diag.FromErr(err)
	}

	d.SetId(strconv.Itoa(d.Get("lb_id").(int)) + "#" + d.Get("name").(string))

	_, err = utilityLBFrontendCheckPresence(ctx, d, m)
	if err != nil {
		return diag.FromErr(err)
	}

	return resourceLBFrontendRead(ctx, d, m)
}

func resourceLBFrontendRead(ctx context.Context, d *schema.ResourceData, m interface{}) diag.Diagnostics {
	log.Debugf("resourceLBFrontendRead")

	f, err := utilityLBFrontendCheckPresence(ctx, d, m)
	if err != nil {
		d.SetId("")
		return diag.FromErr(err)
	}

	lbId, _ := strconv.ParseInt(strings.Split(d.Id(), "#")[0], 10, 32)

	flattenLBFrontend(d, f, lbId)

	return nil
}

func resourceLBFrontendDelete(ctx context.Context, d *schema.ResourceData, m interface{}) diag.Diagnostics {
	log.Debugf("resourceLBFrontendDelete")

	_, err := utilityLBFrontendCheckPresence(ctx, d, m)
	if err != nil {
		return diag.FromErr(err)
	}

	c := m.(*controller.ControllerCfg)
	req := lb.FrontendDeleteRequest{
		LBID:         uint64(d.Get("lb_id").(int)),
		FrontendName: d.Get("name").(string),
	}

	_, err = c.CloudBroker().LB().FrontendDelete(ctx, req)
	if err != nil {
		return diag.FromErr(err)
	}

	d.SetId("")

	return nil
}

func resourceLBFrontendEdit(ctx context.Context, d *schema.ResourceData, m interface{}) diag.Diagnostics {
	return nil
}

func ResourceLBFrontend() *schema.Resource {
	return &schema.Resource{
		SchemaVersion: 1,

		CreateContext: resourceLBFrontendCreate,
		ReadContext:   resourceLBFrontendRead,
		UpdateContext: resourceLBFrontendEdit,
		DeleteContext: resourceLBFrontendDelete,

		Importer: &schema.ResourceImporter{
			StateContext: schema.ImportStatePassthroughContext,
		},

		Timeouts: &schema.ResourceTimeout{
			Create:  &constants.Timeout600s,
			Read:    &constants.Timeout300s,
			Update:  &constants.Timeout300s,
			Delete:  &constants.Timeout300s,
			Default: &constants.Timeout300s,
		},

		Schema: map[string]*schema.Schema{
			"lb_id": {
				Type:        schema.TypeInt,
				Required:    true,
				Description: "ID of the LB instance to backendCreate",
			},
			"backend_name": {
				Type:     schema.TypeString,
				Required: true,
			},
			"name": {
				Type:     schema.TypeString,
				Required: true,
			},
			"bindings": {
				Type:     schema.TypeList,
				Computed: true,
				Elem: &schema.Resource{
					Schema: map[string]*schema.Schema{
						"address": {
							Type:     schema.TypeString,
							Computed: true,
						},
						"guid": {
							Type:     schema.TypeString,
							Computed: true,
						},
						"name": {
							Type:     schema.TypeString,
							Computed: true,
						},
						"port": {
							Type:     schema.TypeInt,
							Computed: true,
						},
					},
				},
			},
			"guid": {
				Type:     schema.TypeString,
				Computed: true,
			},
		},
	}
}

==> 4.7.4.tar.gz: terraform-provider-decort/internal/service/cloudbroker/lb/resource_lb_frontend.go <==
/*
Copyright (c) 2019-2023 Digital Energy Cloud Solutions LLC. All Rights Reserved.
Authors:
Petr Krutov, <petr.krutov@digitalenergy.online>
Stanislav Solovev, <spsolovev@digitalenergy.online>
Kasim Baybikov, <kmbaybikov@basistech.ru>

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

/*
Terraform DECORT provider - manage resources provided by DECORT (Digital Energy Cloud
Orchestration Technology) with Terraform by Hashicorp.

Source code: https://repository.basistech.ru/BASIS/terraform-provider-decort

Please see README.md to learn where to place source code so that it
builds seamlessly.

Documentation: https://repository.basistech.ru/BASIS/terraform-provider-decort/wiki
*/

package lb

import (
	"context"
	"strconv"
	"strings"

	"github.com/hashicorp/terraform-plugin-sdk/v2/diag"
	"github.com/hashicorp/terraform-plugin-sdk/v2/helper/schema"
	log "github.com/sirupsen/logrus"
	"repository.basistech.ru/BASIS/decort-golang-sdk/pkg/cloudbroker/lb"
	"repository.basistech.ru/BASIS/terraform-provider-decort/internal/constants"
	"repository.basistech.ru/BASIS/terraform-provider-decort/internal/controller"
)

func resourceLBFrontendCreate(ctx context.Context, d *schema.ResourceData, m interface{}) diag.Diagnostics {
	log.Debugf("resourceLBFrontendCreate: call for lb_id %d, backend %s to create frontend %s",
		d.Get("lb_id").(int),
		d.Get("backend_name").(string),
		d.Get("name").(string))

	c := m.(*controller.ControllerCfg)

	if diags := checkParamsExistenceLb(ctx, d, c); diags != nil {
		return diags
	}

	req := lb.FrontendCreateRequest{
		BackendName:  d.Get("backend_name").(string),
		LBID:         uint64(d.Get("lb_id").(int)),
		FrontendName: d.Get("name").(string),
	}

	_, err := c.CloudBroker().LB().FrontendCreate(ctx, req)
	if err != nil {
		d.SetId("")
		return diag.FromErr(err)
	}

	d.SetId(strconv.Itoa(d.Get("lb_id").(int)) + "#" + d.Get("name").(string))

	return resourceLBFrontendRead(ctx, d, m)
}

func resourceLBFrontendRead(ctx context.Context, d *schema.ResourceData, m interface{}) diag.Diagnostics {
	log.Debugf("resourceLBFrontendRead: call for id %s", d.Id())

	f, err := utilityLBFrontendCheckPresence(ctx, d, m)
	if err != nil {
		d.SetId("")
		return diag.FromErr(err)
	}

	lbId, _ := strconv.ParseInt(strings.Split(d.Id(), "#")[0], 10, 32)

	flattenLBFrontend(d, f, lbId)

	return nil
}

func resourceLBFrontendDelete(ctx context.Context, d *schema.ResourceData, m interface{}) diag.Diagnostics {
	log.Debugf("resourceLBFrontendDelete: call for id %s", d.Id())

	_, err := utilityLBFrontendCheckPresence(ctx, d, m)
	if err != nil {
		d.SetId("")
		return diag.FromErr(err)
	}

	c := m.(*controller.ControllerCfg)
	req := lb.FrontendDeleteRequest{
		LBID:         uint64(d.Get("lb_id").(int)),
		FrontendName: d.Get("name").(string),
	}

	_, err = c.CloudBroker().LB().FrontendDelete(ctx, req)
	if err != nil {
		return diag.FromErr(err)
	}

	d.SetId("")

	return nil
}

func resourceLBFrontendEdit(ctx context.Context, d *schema.ResourceData, m interface{}) diag.Diagnostics {
	return nil
}

func ResourceLBFrontend() *schema.Resource {
	return &schema.Resource{
		SchemaVersion: 1,

		CreateContext: resourceLBFrontendCreate,
		ReadContext:   resourceLBFrontendRead,
		UpdateContext: resourceLBFrontendEdit,
		DeleteContext: resourceLBFrontendDelete,

		Importer: &schema.ResourceImporter{
			StateContext: schema.ImportStatePassthroughContext,
		},

		Timeouts: &schema.ResourceTimeout{
			Create:  &constants.Timeout600s,
			Read:    &constants.Timeout300s,
			Update:  &constants.Timeout300s,
			Delete:  &constants.Timeout300s,
			Default: &constants.Timeout300s,
		},

		Schema: resourceLbFrontendSchemaMake(),
	}
}
